==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/yrtsubscription/yrtsubscription/notificationorigininfo/notificationorigin/DefaultInterfaceOriginated.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.notificationorigininfo.notificationorigin;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.notificationorigininfo.NotificationOrigin;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of interfaceOriginated.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultInterfaceOriginated extends InnerModelObject implements InterfaceOriginated {
    protected String sourceInterface;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String sourceInterface() {
        return sourceInterface;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void sourceInterface(String sourceInterface) {
        valueLeafFlags.set(LeafIdentifier.SOURCEINTERFACE.getLeafIndex());
        this.sourceInterface = sourceInterface;
    }

    @Override
    public int hashCode() {
        return Objects.hash(sourceInterface, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultInterfaceOriginated) {
            DefaultInterfaceOriginated other = (DefaultInterfaceOriginated) obj;
            return
                Objects.equals(sourceInterface, other.sourceInterface) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("sourceInterface=" + sourceInterface)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultInterfaceOriginated.
     */
    public DefaultInterfaceOriginated() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtsubscription/yrtsubscription/notificationorigininfo/notificationorigin/DefaultInterfaceOriginated.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.notificationorigininfo.notificationorigin;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.notificationorigininfo.NotificationOrigin;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of interfaceOriginated.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultInterfaceOriginated extends InnerModelObject implements InterfaceOriginated {
    protected String sourceInterface;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String sourceInterface() {
        return sourceInterface;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void sourceInterface(String sourceInterface) {
        valueLeafFlags.set(LeafIdentifier.SOURCEINTERFACE.getLeafIndex());
        this.sourceInterface = sourceInterface;
    }

    @Override
    public int hashCode() {
        return Objects.hash(sourceInterface, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultInterfaceOriginated) {
            DefaultInterfaceOriginated other = (DefaultInterfaceOriginated) obj;
            return
                Objects.deepEquals(sourceInterface, other.sourceInterface) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("sourceInterface=" + sourceInterface)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultInterfaceOriginated.
     */
    public DefaultInterfaceOriginated() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
